use tool_helper::{Input, Output, Result};
pub use tool_helper::Error;

pub enum LineFeed {
    Unix,
    Windows
}

pub enum FileType {
    CHeader,
    CSource,
    CPPHeader,
    CPPSource,
}

pub struct Configuration {
    pub file_name:     String,
    pub data_name:     String,
    pub line_feed:     LineFeed,
    pub file_type:     FileType,
}

struct FileVariables<'a> {
    include:  &'a str,
    var_type: &'a str,
}

const UNIX_LINEFEED:    &'static str = "\n";
const WINDOWS_LINEFEED: &'static str = "\r\n";

const   C_VARIABLES: FileVariables = FileVariables{include: "", var_type: "char"};
const CPP_VARIABLES: FileVariables = FileVariables{include: "#include <stdint.h>", var_type: "uint8_t"};

fn write_source_file(variables: &FileVariables, input: Input, output: &mut Output, line_feed: &str) -> Result<()> {
    Error::try_or_new(write!(output, "{}{}{}", variables.include, line_feed, line_feed), None)?;
    Error::try_or_new(write!(output, "const {} data[] = {{{}", variables.var_type, line_feed), None)?;
    Error::try_or_new(write!(output, "}};"), None)?;
    
    Ok(())
}

pub fn convert(_cfg: Configuration, _input: Input, mut output: Output) -> Result<()> {
    write_source_file(&CPP_VARIABLES, _input, &mut output, WINDOWS_LINEFEED)
}